package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;

import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;
import com.steerinfo.dil.model.OmsshipShipmentInstructions;
import com.steerinfo.dil.service.IOmsshipShipmentInstructionsService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.math.BigDecimal;

/**
 * OmsshipShipmentInstructions RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-20 03:05
 * 类描述
 * 修订历史：
 * 日期：2021-08-20
 * 作者：generator
 * 参考：
 * 描述：OmsshipShipmentInstructions RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/omsshipshipmentinstructions")
public class OmsshipShipmentInstructionsController extends BaseRESTfulController {

    @Autowired
    IOmsshipShipmentInstructionsService omsshipShipmentInstructionsService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;
    /**
     * 新增
     * @param omsshipShipmentInstructions
     * @return
     */
    @ApiOperation(value="新增", notes="根据OmsshipShipmentInstructions对象创建")
    @ApiImplicitParam(name = "omsshipShipmentInstructions", value = "详细实体omsshipShipmentInstructions", required = true, dataType = "OmsshipShipmentInstructions", paramType = "java.util.Map")
    @PostMapping(value = "/addShipmentInstructions")
    public RESTfulResult addShipmentInstructions(@RequestBody OmsshipShipmentInstructions omsshipShipmentInstructions){
        int code=omsshipShipmentInstructionsService.insert(omsshipShipmentInstructions);
        return success(code);
    }

    /**
     * 查询
     * @param instructionsId
     * @return
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "instructionsId", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getShipmentInstructions/{instructionsId}")
    public RESTfulResult getShipmentInstructions(@PathVariable("instructionsId") BigDecimal instructionsId){
        List<Map<String,Object>> map = omsshipShipmentInstructionsService.selectShipmentInstructions(instructionsId);
        return success(map);
    }

    /**
     * 修改
     * @param omsshipShipmentInstructions
     * @return
     */
    @ApiOperation(value="更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "omsshipShipmentInstructions", value = "详细实体omsshipShipmentInstructions", required = true, dataType = "OmsshipShipmentInstructions")
    })
    @PostMapping(value = "/updateShipmentInstructions")
    public RESTfulResult updateShipmentInstructions(@RequestBody OmsshipShipmentInstructions omsshipShipmentInstructions){
        int code = omsshipShipmentInstructionsService.updateByPrimaryKey(omsshipShipmentInstructions);
        return success(code);
    }

    /**
     * 删除
     * @param instructionsId
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "BigDecimal", name = "instructionsId", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/deleteByPrimaryKey/{instructionsId}")
    public RESTfulResult deleteByPrimaryKey(@PathVariable("instructionsId") BigDecimal instructionsId){
        omsshipShipmentInstructionsService.deleteByPrimaryKey(instructionsId);
        return success();
    }

    /**
     * 展示所有装船指令
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示装船指令表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "74", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getShipMentInstructionsList")
    public RESTfulResult getShipMentInstructionsList(@RequestBody(required = false) Map<String,Object> mapVal,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId,
                                                     String con){
        //框计算
        if(con != null){
            if(!"undefined".equals(con)){
                //设置要查询的索引名称
                String index="get_ship_instruction_list";
                //获取查询结果
                return success(esFeign.getConResult(mapVal,index,apiId,pageNum,pageSize,con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> detailListTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapVal == null) {
            //将查询结果存入索引中
            detailListTotal = omsshipShipmentInstructionsService.selectAll(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_ship_instruction_list");
            //添加id
            map.put("indexId", "shipmentInstructionsId");
            detailListTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(detailListTotal);
            esFeign.insertIndex(detailListTotal);
            //删除
            detailListTotal.remove(detailListTotal.size() - 1);
        }
        if (detailListTotal == null) {
            detailListTotal = omsshipShipmentInstructionsService.selectAll(mapVal);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = omsshipShipmentInstructionsService.selectAll(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, detailListTotal, columnList);
        return success(data);

    }

    /**
     * 修改下发状态
     * @param shipmentInstructionsId
     * @return
     */
    @ApiOperation(value="修改下发状态")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "shipmentInstructionsId", value = "主键id", required = true, dataType = "BigDecimal")
    })
    @PostMapping(value = "/updateIssueStatus/{shipmentInstructionsId}")
    public RESTfulResult updateIssueStatus(@PathVariable("shipmentInstructionsId") BigDecimal shipmentInstructionsId){
        int code = omsshipShipmentInstructionsService.updateIssueStatus(shipmentInstructionsId);
        return success(code);
    }

    /**
     * 获取批次id
     * @return
     */
    @GetMapping("getBatchId")
    @ApiOperation(value = "获取批次id下拉列表")
    public RESTfulResult getBatchId(){
        return success(omsshipShipmentInstructionsService.getBatchId());
    }

}
